from setuptools import setup

setup(name='generalDistributions',
      version='0.2',
      description='Gaussian distributions',
      packages=['generalDistributions'],
      author = 'abdelwahid benzerrouk',
      author_email = 'benzerrouk.wahid@gmail.com',
      zip_safe=False)
